/*@C:\Web_511\Sql\End_Conv\Oracle\9070_GEPSTPO_CALCULA_CRONOGRAMA.SQL*/

CREATE OR REPLACE PROCEDURE CALCULA_CRONOGRAMA(
   P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
   P_CDPROJETO    IN PROJETO.CDPROJETO%TYPE,
   P_NRBASELINEPR IN CRONOPROJETO.NRBASELINEPR%TYPE,
   P_CDVERCRONPRJ IN CRONOPROJETO.CDVERCRONPRJ%TYPE,
   P_DTDATABASE   IN CRONOPROJETO.DTINIITCRPRJ%TYPE)
AS
   V_DATAINI      DATE;
   V_DATAFIM      DATE;
   V_DATAINIPRJ   DATE;
   V_DATAFIMPRJ   DATE;
   V_DATA         DATE;
   V_SEQUENCIAL   VARCHAR2(4);
   V_DIAS         FLOAT;
   V_TOTAATIV     FLOAT;
   V_DTBASEMEVOL  DATE;
   V_DTBASEHOMO   DATE;
   V_IDTIPOPROJ   VARCHAR2(1);
   V_DTFINITCRPRJ DATE;
   V_DATAINITF    DATE;
   V_DATAFIMTF    DATE;
   V_DIASTF       FLOAT;
BEGIN
   V_DATAINIPRJ := NULL;
   V_DATAFIMPRJ := NULL;

   SELECT MAX(C.DTINIITCRPRJ), MAX(C.DTFINITCRPRJ)
     INTO V_DATAINIPRJ, V_DATAFIMPRJ
     FROM CRONOPROJETO C
    WHERE C.CDFILIAL = P_CDFILIAL
      AND C.CDPROJETO = P_CDPROJETO
      AND C.NRBASELINEPR = P_NRBASELINEPR
      AND C.CDVERCRONPRJ = P_CDVERCRONPRJ
      AND C.CDNIVELITPRJ = '1';

   /* Apaga as datas antes de calcular */
   UPDATE CRONOPROJETO C
      SET QTHRANTPATIVTAR = NULL,
          DTINIITCRPRJ = NULL,
          DTFINITCRPRJ = NULL
    WHERE C.CDFILIAL     = P_CDFILIAL
      AND C.CDPROJETO    = P_CDPROJETO
      AND C.NRBASELINEPR = P_NRBASELINEPR
      AND C.CDVERCRONPRJ = P_CDVERCRONPRJ
      AND EXISTS (SELECT CR.CDFILIAL||CR.NRTAREFA||CR.NRPLATIVTARE
                    FROM CRONOPROJETO CR, PLANATIVTARE PL
                   WHERE CR.CDFILIAL = P_CDFILIAL
                     AND CR.CDPROJETO = P_CDPROJETO
                     AND CR.CDVERCRONPRJ = (SELECT MAX(CDVERCRONPRJ)
                                              FROM CRONOPROJETO D
                                             WHERE D.CDFILIAL     = CR.CDFILIAL
                                               AND D.CDPROJETO    = CR.CDPROJETO
                                               AND D.CDVERCRONPRJ = NVL(P_CDVERCRONPRJ, D.CDVERCRONPRJ))
                     AND C.CDFILIAL      = PL.CDFILIAL
                     AND C.NRTAREFA      = PL.NRTAREFA
                     AND C.NRPLATIVTARE  = PL.NRPLATIVTARE
                     AND CR.CDFILIAL     = PL.CDFILIAL
                     AND CR.NRTAREFA     = PL.NRTAREFA
                     AND CR.NRPLATIVTARE = PL.NRPLATIVTARE
                     AND PL.IDSITATIVTAR <> 'C'
                     AND PL.IDSITATIVTAR <> 'X');

   /* Apaga as horas das atividades que no foram incluidas pelo cronograma e que cujas as horas no tenham sido alteradas manualmente */
   UPDATE CRONOPROJETO C
      SET NRDIASITCRPJ = NULL
    WHERE C.CDFILIAL     = P_CDFILIAL
      AND C.CDPROJETO    = P_CDPROJETO
      AND C.NRBASELINEPR = P_NRBASELINEPR
      AND C.CDVERCRONPRJ = P_CDVERCRONPRJ
      AND EXISTS (SELECT CR.CDFILIAL||CR.NRTAREFA||CR.NRPLATIVTARE
                    FROM CRONOPROJETO CR, PLANATIVTARE PL
                   WHERE CR.CDFILIAL = P_CDFILIAL
                     AND CR.CDPROJETO = P_CDPROJETO
                     AND CR.CDVERCRONPRJ = (SELECT MAX(CDVERCRONPRJ)
                                              FROM CRONOPROJETO D
                                             WHERE D.CDFILIAL     = CR.CDFILIAL
                                               AND D.CDPROJETO    = CR.CDPROJETO
                                               AND D.CDVERCRONPRJ = NVL(P_CDVERCRONPRJ, D.CDVERCRONPRJ))
                     AND C.CDFILIAL      = PL.CDFILIAL
                     AND C.NRTAREFA      = PL.NRTAREFA
                     AND C.NRPLATIVTARE  = PL.NRPLATIVTARE
                     AND CR.CDFILIAL     = PL.CDFILIAL
                     AND CR.NRTAREFA     = PL.NRTAREFA
                     AND CR.NRPLATIVTARE = PL.NRPLATIVTARE
                     AND PL.IDSITATIVTAR <> 'C'
                     AND PL.IDSITATIVTAR <> 'X'
                     AND PL.IDATVTEMPALTCR = 'N'
                     AND PL.IDATIVINCLCRONO = 'N');

   DELETE FROM OCUPAOPERPROJ
    WHERE CDFILIAL  = P_CDFILIAL
      AND CDPROJETO = P_CDPROJETO;

   IF P_DTDATABASE IS NULL THEN
      SELECT NVL(MAX(DTINIPLANPRJ),SYSDATE)
      INTO V_DATAINI
      FROM PROJETO
      WHERE CDFILIAL  = P_CDFILIAL AND
            CDPROJETO = P_CDPROJETO;
   ELSE
      V_DATAINI := P_DTDATABASE;
   END IF;

   /* Atividades por operador e fila de prioridade */
   FOR C_TAREFAS IN (SELECT C.CDSEQCRONPRJ, C.NRSOLISERV, C.NRTAREFA, C.NRPLATIVTARE, C.CDFILAPRIO, C.CDPRECITCRPJ,
                            C.CDOPERADOR
                       FROM CRONOPROJETO C, PLANATIVTARE P
                      WHERE C.CDFILIAL     = P_CDFILIAL      AND
                            C.CDPROJETO    = P_CDPROJETO     AND
                            C.NRBASELINEPR = P_NRBASELINEPR  AND
                            C.CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                            C.CDNIVELITPRJ = '3' AND
                            C.CDFILIAL     = P.CDFILIAL      AND
                            C.NRTAREFA     = P.NRTAREFA      AND
                            C.NRPLATIVTARE = P.NRPLATIVTARE  AND
                            P.IDSITATIVTAR <> 'C'            AND
                            P.IDSITATIVTAR <> 'X'
                      ORDER BY C.CDOPERADOR, C.CDFILAPRIO) LOOP
       CALCULA_DATAS(P_CDFILIAL, P_CDPROJETO, P_NRBASELINEPR, P_CDVERCRONPRJ, C_TAREFAS.CDOPERADOR, C_TAREFAS.CDFILAPRIO, V_DATAINI);
   END LOOP;


   /*Calcula as datas das solicitaes*/
   FOR C_SOLICITA IN (SELECT CDSEQCRONPRJ, NRSOLISERV, CDFILAPRIO, CDPRECITCRPJ,
                             CDOPERADOR, NRTAREFA, NRPLATIVTARE
                        FROM CRONOPROJETO
                       WHERE CDFILIAL     = P_CDFILIAL      AND
                             CDPROJETO    = P_CDPROJETO     AND
                             NRBASELINEPR = P_NRBASELINEPR  AND
                             CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                             CDNIVELITPRJ = '2'
                       ORDER BY CDOPERADOR, CDFILAPRIO) LOOP

       /*Calcula as datas das tarefas*/
      FOR C_TAREFA IN (SELECT DISTINCT CDSEQCRONPRJ, NRSOLISERV, CDFILAPRIO, CDPRECITCRPJ,
                              CDOPERADOR, NRTAREFA
                        FROM CRONOPROJETO
                       WHERE CDFILIAL     = P_CDFILIAL      AND
                             CDPROJETO    = P_CDPROJETO     AND
                             NRBASELINEPR = P_NRBASELINEPR  AND
                             CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                             CDNIVELITPRJ = 'T'
                       ORDER BY CDOPERADOR, CDFILAPRIO) LOOP

         SELECT MIN(C.DTINIITCRPRJ), MAX(C.DTFINITCRPRJ), SUM(C.NRDIASITCRPJ)
           INTO V_DATAINITF, V_DATAFIMTF, V_DIASTF
           FROM CRONOPROJETO C, PLANATIVTARE P
          WHERE C.CDFILIAL     = P_CDFILIAL      AND
                C.CDPROJETO    = P_CDPROJETO     AND
                C.NRBASELINEPR = P_NRBASELINEPR  AND
                C.CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                C.CDNIVELITPRJ = '3'             AND
                C.NRSOLISERV   = C_SOLICITA.NRSOLISERV AND
                C.NRTAREFA     = C_TAREFA.NRTAREFA AND
                C.CDFILIAL     = P.CDFILIAL      AND
                C.NRTAREFA     = P.NRTAREFA      AND
                C.NRPLATIVTARE = P.NRPLATIVTARE  AND
                P.IDSITATIVTAR <> 'X';

         IF V_DATAINITF IS NOT NULL THEN
            UPDATE CRONOPROJETO
               SET NRDIASITCRPJ    = V_DIASTF,
                   QTHRANTPATIVTAR = V_DIASTF,
                   DTINIITCRPRJ    = V_DATAINITF,
                   DTFINITCRPRJ    = V_DATAFIMTF
             WHERE CDFILIAL     = P_CDFILIAL      AND
                   CDPROJETO    = P_CDPROJETO     AND
                   NRBASELINEPR = P_NRBASELINEPR  AND
                   CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                   CDNIVELITPRJ = 'T'             AND
                   NRSOLISERV   = C_SOLICITA.NRSOLISERV AND
		   NRTAREFA = C_TAREFA.NRTAREFA;
         END IF;
      END LOOP;

      SELECT MIN(C.DTINIITCRPRJ), MAX(C.DTFINITCRPRJ), SUM(C.NRDIASITCRPJ)
        INTO V_DATAINI, V_DATAFIM, V_DIAS
        FROM CRONOPROJETO C, PLANATIVTARE P
       WHERE C.CDFILIAL     = P_CDFILIAL      AND
             C.CDPROJETO    = P_CDPROJETO     AND
             C.NRBASELINEPR = P_NRBASELINEPR  AND
             C.CDVERCRONPRJ = P_CDVERCRONPRJ  AND
             C.CDNIVELITPRJ = '3'             AND
             C.NRSOLISERV   = C_SOLICITA.NRSOLISERV AND
             C.CDFILIAL     = P.CDFILIAL      AND
             C.NRTAREFA     = P.NRTAREFA      AND
             C.NRPLATIVTARE = P.NRPLATIVTARE  AND
             P.IDSITATIVTAR <> 'X';

      UPDATE CRONOPROJETO
         SET NRDIASITCRPJ    = V_DIAS,
             QTHRANTPATIVTAR = V_DIAS,
             DTINIITCRPRJ    = V_DATAINI,
             DTFINITCRPRJ    = V_DATAFIM
       WHERE CDFILIAL     = P_CDFILIAL      AND
             CDPROJETO    = P_CDPROJETO     AND
             NRBASELINEPR = P_NRBASELINEPR  AND
             CDVERCRONPRJ = P_CDVERCRONPRJ  AND
             CDNIVELITPRJ = '2'             AND
             NRSOLISERV   = C_SOLICITA.NRSOLISERV;
   END LOOP;


   /* Atualiza as datas do projeto na tabela de cronograma */
   SELECT MIN(DTINIITCRPRJ), MAX(DTFINITCRPRJ), SUM(NRDIASITCRPJ)
   INTO V_DATAINI, V_DATAFIM, V_DIAS
   FROM CRONOPROJETO
   WHERE CDFILIAL     = P_CDFILIAL      AND
         CDPROJETO    = P_CDPROJETO     AND
         NRBASELINEPR = P_NRBASELINEPR  AND
         CDNIVELITPRJ = '2'             AND
         CDVERCRONPRJ = P_CDVERCRONPRJ;

   UPDATE CRONOPROJETO
   SET NRDIASITCRPJ = V_DIAS,
       QTHRANTPATIVTAR = V_DIAS,
       NRORDERCRONO = '0001',
       DTINIITCRPRJ = V_DATAINI,
       DTFINITCRPRJ = V_DATAFIM
   WHERE CDFILIAL     = P_CDFILIAL      AND
         CDPROJETO    = P_CDPROJETO     AND
         NRBASELINEPR = P_NRBASELINEPR  AND
         CDVERCRONPRJ = P_CDVERCRONPRJ  AND
         CDNIVELITPRJ = '1';

   /*GERA A ORDENAO DO CRONOGRAMA*/
   V_SEQUENCIAL := '0001';

   SELECT IDTIPOPROJETO
     INTO V_IDTIPOPROJ
     FROM PROJETO
    WHERE CDFILIAL  = P_CDFILIAL
      AND CDPROJETO = P_CDPROJETO;

   IF V_IDTIPOPROJ = '4' THEN
   /*PARA PROJETOS DO TIPO OPERACIONAL*/
      /*Ordena as solicitaes por data para gerar a ordenao do cronograma */
      FOR C_SOLICITA IN (SELECT CDSEQCRONPRJ, NRSOLISERV, CDFILAPRIO, CDPRECITCRPJ, CDOPERADOR
                           FROM CRONOPROJETO
                          WHERE CDFILIAL     = P_CDFILIAL      AND
                                CDPROJETO    = P_CDPROJETO     AND
                                NRBASELINEPR = P_NRBASELINEPR  AND
                                CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                                CDNIVELITPRJ = '2'
                          ORDER BY DTINIITCRPRJ, NVL(CDPRECITCRPJ,0), CDOPERADOR, CDFILAPRIO) LOOP

         V_SEQUENCIAL := RPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUENCIAL)+ 1)), 4, '0');

         UPDATE CRONOPROJETO
            SET NRORDERCRONO = V_SEQUENCIAL
          WHERE CDFILIAL     = P_CDFILIAL              AND
                CDPROJETO    = P_CDPROJETO             AND
                NRBASELINEPR = P_NRBASELINEPR          AND
                CDVERCRONPRJ = P_CDVERCRONPRJ          AND
                CDSEQCRONPRJ = C_SOLICITA.CDSEQCRONPRJ AND
                CDNIVELITPRJ = '2';

         FOR C_TAREFA IN (SELECT CDSEQCRONPRJ, NRSOLISERV, NRTAREFA, CDFILAPRIO, CDPRECITCRPJ
                            FROM CRONOPROJETO
               	      	   WHERE CDFILIAL     = P_CDFILIAL      AND
                                 CDPROJETO    = P_CDPROJETO     AND
                                 NRBASELINEPR = P_NRBASELINEPR  AND
                                 CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                                 NRSOLISERV   = C_SOLICITA.NRSOLISERV AND
                                 CDNIVELITPRJ = 'T'
                           ORDER BY DTINIITCRPRJ, CDFILAPRIO, NRSOLISERV, NRTAREFA) LOOP

            /*V_SEQUENCIAL := RPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUENCIAL)+ 1000)), 4, '0');*/
            V_SEQUENCIAL := RPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUENCIAL)+ 1)), 4, '0');

            UPDATE CRONOPROJETO
               SET NRORDERCRONO = V_SEQUENCIAL
             WHERE CDFILIAL     = P_CDFILIAL              AND
                   CDPROJETO    = P_CDPROJETO             AND
                   NRBASELINEPR = P_NRBASELINEPR          AND
                   CDVERCRONPRJ = P_CDVERCRONPRJ          AND
                   NRSOLISERV   = C_TAREFA.NRSOLISERV AND
                   NRTAREFA   = C_TAREFA.NRTAREFA AND
                   CDNIVELITPRJ = 'T';

            FOR C_ATIVIDADE IN (SELECT CDSEQCRONPRJ, NRSOLISERV, NRTAREFA, NRPLATIVTARE, CDFILAPRIO,
                                       DTINIITCRPRJ, DTFINITCRPRJ
                                  FROM CRONOPROJETO
                                 WHERE CDFILIAL     = P_CDFILIAL      AND
                                       CDPROJETO    = P_CDPROJETO     AND
                                       NRBASELINEPR = P_NRBASELINEPR  AND
                                       CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                                       NRSOLISERV   = C_TAREFA.NRSOLISERV AND
                                       NRTAREFA   = C_TAREFA.NRTAREFA AND
                                       CDNIVELITPRJ = '3'
                                 ORDER BY DTINIITCRPRJ, CDOPERADOR, CDFILAPRIO, NRSOLISERV, NRTAREFA,
                                          NRPLATIVTARE) LOOP
                                /*ORDER BY DTINIITCRPRJ, CDOPERADOR, CDFILAPRIO, NVL(CDPRECITCRPJ,0)) LOOP*/

               V_SEQUENCIAL := RPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUENCIAL)+ 1)), 4, '0');

               UPDATE CRONOPROJETO
                  SET NRORDERCRONO = V_SEQUENCIAL
                WHERE CDFILIAL     = P_CDFILIAL               AND
                      CDPROJETO    = P_CDPROJETO              AND
                      NRBASELINEPR = P_NRBASELINEPR           AND
                      CDVERCRONPRJ = P_CDVERCRONPRJ           AND
                      NRSOLISERV   = C_ATIVIDADE.NRSOLISERV AND
                      NRTAREFA   = C_ATIVIDADE.NRTAREFA AND
                      NRPLATIVTARE   = C_ATIVIDADE.NRPLATIVTARE AND
                      CDNIVELITPRJ = '3';

               UPDATE PLANATIVTARE
                  SET DTINPATIVTAR = C_ATIVIDADE.DTINIITCRPRJ,
                      DTFIPATIVTAR = C_ATIVIDADE.DTFINITCRPRJ
                WHERE CDFILIAL     = P_CDFILIAL           AND
                      NRTAREFA     = C_ATIVIDADE.NRTAREFA AND
                      NRPLATIVTARE = C_ATIVIDADE.NRPLATIVTARE;
            END LOOP;   /*Atividades*/
         END LOOP;   /*Tarefas*/
      END LOOP;  /*Solicitao*/
   ELSE
   /*PARA OS OUTROS PROJETOS*/
      /*Ordena as solicitaes por data para gerar a ordenao do cronograma */
      FOR C_SOLICITA IN (SELECT CDSEQCRONPRJ, NRSOLISERV, CDFILAPRIO, CDPRECITCRPJ,
                                CDOPERADOR
                           FROM CRONOPROJETO
                          WHERE CDFILIAL     = P_CDFILIAL      AND
                                CDPROJETO    = P_CDPROJETO     AND
                                NRBASELINEPR = P_NRBASELINEPR  AND
                                CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                                CDNIVELITPRJ = '2'
                          ORDER BY DTINIITCRPRJ, NVL(CDPRECITCRPJ,0), CDOPERADOR, CDFILAPRIO) LOOP

         V_SEQUENCIAL := RPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUENCIAL)+ 1)), 4, '0');

         UPDATE CRONOPROJETO
            SET NRORDERCRONO = V_SEQUENCIAL
          WHERE CDFILIAL     = P_CDFILIAL              AND
                CDPROJETO    = P_CDPROJETO             AND
                NRBASELINEPR = P_NRBASELINEPR          AND
                CDVERCRONPRJ = P_CDVERCRONPRJ          AND
                CDSEQCRONPRJ = C_SOLICITA.CDSEQCRONPRJ AND
                CDNIVELITPRJ = '2';

         FOR C_ATIVIDADE IN (SELECT CDSEQCRONPRJ, NRSOLISERV, NRTAREFA, NRPLATIVTARE, CDFILAPRIO,
                                    DTINIITCRPRJ, DTFINITCRPRJ
                               FROM CRONOPROJETO
                              WHERE CDFILIAL     = P_CDFILIAL      AND
                                    CDPROJETO    = P_CDPROJETO     AND
                                    NRBASELINEPR = P_NRBASELINEPR  AND
                                    CDVERCRONPRJ = P_CDVERCRONPRJ  AND
                                    CDNIVELITPRJ = '3'             AND
                                    NRSOLISERV   = C_SOLICITA.NRSOLISERV
                              ORDER BY DTINIITCRPRJ, CDOPERADOR, CDFILAPRIO, NVL(CDPRECITCRPJ,0)) LOOP

            V_SEQUENCIAL := RPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUENCIAL)+ 1)), 4, '0');

            UPDATE CRONOPROJETO
               SET NRORDERCRONO = V_SEQUENCIAL
             WHERE CDFILIAL     = P_CDFILIAL               AND
                   CDPROJETO    = P_CDPROJETO              AND
                   NRBASELINEPR = P_NRBASELINEPR           AND
                   CDVERCRONPRJ = P_CDVERCRONPRJ           AND
                   CDSEQCRONPRJ = C_ATIVIDADE.CDSEQCRONPRJ AND
                   CDNIVELITPRJ = '3';

            UPDATE PLANATIVTARE
               SET DTINPATIVTAR = C_ATIVIDADE.DTINIITCRPRJ,
                   DTFIPATIVTAR = C_ATIVIDADE.DTFINITCRPRJ
             WHERE CDFILIAL     = P_CDFILIAL           AND
                   NRTAREFA     = C_ATIVIDADE.NRTAREFA AND
                   NRPLATIVTARE = C_ATIVIDADE.NRPLATIVTARE;
         END LOOP;   /*Atividades*/
      END LOOP;  /*Solicitao*/
   END IF;

   UPDATE CRONOPROJETO C
   SET DTFINITCRPRJ = (SELECT NVL(MAX(DTCOMPROMISS),DTFINITCRPRJ)
                       FROM SOLISERV S
                       WHERE S.CDFILIAL = C.CDFILIAL
                         AND S.NRSOLISERV = C.NRSOLISERV)
   WHERE CDFILIAL     = P_CDFILIAL     AND
         CDPROJETO    = P_CDPROJETO    AND
         NRBASELINEPR = P_NRBASELINEPR AND
         CDVERCRONPRJ = P_CDVERCRONPRJ AND
         CDNIVELITPRJ = '2'            AND
         IDMARCOPROJ  = 'S';

   SELECT
      BGR.DTFPATCHGRPROJ,
      P.IDTIPOPROJETO
   INTO
      V_DTBASEMEVOL,
      V_IDTIPOPROJ
   FROM
      PROJETO P,
      BASELINEGRPROJ BGR
   WHERE
      P.CDFILIAL     = P_CDFILIAL     AND
      P.CDPROJETO    = P_CDPROJETO    AND
      BGR.NRBASEGRPR = P_NRBASELINEPR AND
      P.CDGRUPOPROJ  = BGR.CDGRUPOPROJ;

   IF V_DTBASEMEVOL < V_DATAFIM THEN
      raise_application_error(-20502, 'MEVOL', false);
   END IF;

   /*Grava a Data Inicial, Concluso do Projeto e da ltima atividade gerada quando o projeto foi
   criado pela primeira vez*/
   IF (V_DATAINIPRJ IS NULL) OR
      (V_DATAFIMPRJ IS NULL) THEN
      UPDATE BASELINEPROJ
         SET DTINIBASELINE = V_DATAINI,
             DTFINBASELINE = V_DATAFIM,
             DTFINULTATIVBL = V_DATAFIM
       WHERE CDFILIAL = P_CDFILIAL
         AND CDPROJETO = P_CDPROJETO
         AND NRBASELINEPR = P_NRBASELINEPR;
   ELSE
   /*Grava a Data Final da ltima atividade do Cronograma*/
      UPDATE BASELINEPROJ
         SET DTFINULTATIVBL = V_DATAFIM
       WHERE CDFILIAL = P_CDFILIAL
         AND CDPROJETO = P_CDPROJETO
         AND NRBASELINEPR = P_NRBASELINEPR;
   END IF;
END;
/


-- VERSAO --
BEGIN ATUVEROBJ('CALCULA_CRONOGRAMA','5.11.001'); END;
/

